gzz-commits
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Gzz-commits] gzz ./TODO Documentation/Manuscripts/gzigzag.bi...


From: Tuomas J. Lukka
Subject: [Gzz-commits] gzz ./TODO Documentation/Manuscripts/gzigzag.bi...
Date: Sun, 01 Dec 2002 17:39:35 -0500

CVSROOT:        /cvsroot/gzz
Module name:    gzz
Changes by:     Tuomas J. Lukka <address@hidden>        02/12/01 17:39:35

Modified files:
        .              : TODO 
        Documentation/Manuscripts: gzigzag.bib 
        Documentation/Manuscripts/Paper: paper.tex 
        gfx/demo       : papertest.py xupdf.py 
        gzz/view       : xubuoy.py 

Log message:
        twids

CVSWeb URLs:
http://savannah.gnu.org/cgi-bin/viewcvs/gzz/gzz/TODO.diff?tr1=1.429&tr2=1.430&r1=text&r2=text
http://savannah.gnu.org/cgi-bin/viewcvs/gzz/gzz/Documentation/Manuscripts/gzigzag.bib.diff?tr1=1.84&tr2=1.85&r1=text&r2=text
http://savannah.gnu.org/cgi-bin/viewcvs/gzz/gzz/Documentation/Manuscripts/Paper/paper.tex.diff?tr1=1.220&tr2=1.221&r1=text&r2=text
http://savannah.gnu.org/cgi-bin/viewcvs/gzz/gzz/gfx/demo/papertest.py.diff?tr1=1.55&tr2=1.56&r1=text&r2=text
http://savannah.gnu.org/cgi-bin/viewcvs/gzz/gzz/gfx/demo/xupdf.py.diff?tr1=1.56&tr2=1.57&r1=text&r2=text
http://savannah.gnu.org/cgi-bin/viewcvs/gzz/gzz/gzz/view/xubuoy.py.diff?tr1=1.36&tr2=1.37&r1=text&r2=text

Patches:
Index: gzz/Documentation/Manuscripts/Paper/paper.tex
diff -u gzz/Documentation/Manuscripts/Paper/paper.tex:1.220 
gzz/Documentation/Manuscripts/Paper/paper.tex:1.221
--- gzz/Documentation/Manuscripts/Paper/paper.tex:1.220 Sun Dec  1 17:30:44 2002
+++ gzz/Documentation/Manuscripts/Paper/paper.tex       Sun Dec  1 17:39:34 2002
@@ -604,7 +604,8 @@
 %color space is reasonably perceptually uniform.
 
 Hues are chosen from a distribution which usually clusters
-them fairly close together but also allows far-away hues
+them fairly close together around a uniformly chosen mean
+but also allows far-away hues
 in the same palette occasionally.
 The saturations are chosen from distribution emphasizing
 saturated colors: unsaturated colors can easily cause a too multicolored
@@ -985,8 +986,7 @@
 as opposed to 2 and 2 on NV10, 
 using 2 passes as we currently do is too much; 
 it should be possible to obtain interesting textures with just one pass.
-
-We are working on implementing
+We are also working on implementing
 these algorithms on ATI's extensions, due to their recent release
 of a Linux driver. 
 
@@ -1032,7 +1032,7 @@
 
 OTHER IDENTITY: EDGE SHAPE
 
-NONREP: BAD HW ACCEL?
+% NONREP: BAD HW ACCEL?
 
 
 % \section{MPEG Animation}
Index: gzz/Documentation/Manuscripts/gzigzag.bib
diff -u gzz/Documentation/Manuscripts/gzigzag.bib:1.84 
gzz/Documentation/Manuscripts/gzigzag.bib:1.85
--- gzz/Documentation/Manuscripts/gzigzag.bib:1.84      Sun Dec  1 11:23:03 2002
+++ gzz/Documentation/Manuscripts/gzigzag.bib   Sun Dec  1 17:39:34 2002
@@ -1989,7 +1989,7 @@
 
 @book{ bruce96visualperception,
   author = "Vicki Bruce and Patrick R. Green and Mark A. Georgeson",
-  title = "Visual Preception: Physiology, Psychology, and Ecology, 3rd 
edition",
+  title = "Visual Perception: Physiology, Psychology, and Ecology, 3rd 
edition",
   year = "1996",
   publisher = "Psychology Press",
 }
Index: gzz/TODO
diff -u gzz/TODO:1.429 gzz/TODO:1.430
--- gzz/TODO:1.429      Sat Nov 30 08:10:23 2002
+++ gzz/TODO    Sun Dec  1 17:39:34 2002
@@ -12,7 +12,9 @@
 0.8alpha4: Cleanup release after crucial demos; make it possible for anyone to
            get *THE* demo up and running
     jvk:
-       - find sutherland sketchpad ref
+       - TOCs
+       - ResearchIndex ref.
+
        - calculate size of 2D basis textures: number of RGBA texels in base 
level.
        - make callgl complain on broken stuff such as 
          the string "%(texid)s" in place of a number !!!!
Index: gzz/gfx/demo/papertest.py
diff -u gzz/gfx/demo/papertest.py:1.55 gzz/gfx/demo/papertest.py:1.56
--- gzz/gfx/demo/papertest.py:1.55      Sat Nov 30 04:23:57 2002
+++ gzz/gfx/demo/papertest.py   Sun Dec  1 17:39:34 2002
@@ -89,7 +89,7 @@
     global benchmark
     if benchmark:
         benchmark = 0
-        iters = 10
+        iters = 100
         t = w.timeRender(vs, iters)
         print "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!Time of", iters, "renders:", 
t, "s"
 
Index: gzz/gfx/demo/xupdf.py
diff -u gzz/gfx/demo/xupdf.py:1.56 gzz/gfx/demo/xupdf.py:1.57
--- gzz/gfx/demo/xupdf.py:1.56  Sun Dec  1 10:20:28 2002
+++ gzz/gfx/demo/xupdf.py       Sun Dec  1 17:39:34 2002
@@ -5,6 +5,7 @@
 
 from gzz.index import XuLink
 from gzz.gfx.gl import Stencil
+from gfx.libutil import saveanim
 
 from jarray import array, zeros
 
@@ -78,6 +79,26 @@
 def globalkey(key):
     if '1' <= key <= '9':
         currentScene.moveToCell(cells[ord(key) - ord('1')])
+    if key == 'P':
+       makeShots()
+
+w.setLocation(950, 0, 1500, 1000)
+def makeShots():
+    scene = gzz.view.xubuoy.XuPDFScene_PDFContext(xuspace)
+    # scene.bgcolor = (.9, .9, .8)
+
+    def frame(fileprefix):
+       vs = w.createVobScene()
+       scene.scene(vs)
+       w.renderStill(vs, 0)
+       saveanim.saveframe("shots/%s.png" % fileprefix, w)
+
+    scene.moveToCell(cells[0], 1.05, .22)
+    frame("xupdf1")
+    scene.moveToCell(cells[1], 1.7, .7)
+    frame("xupdf2")
+    print "FRAME DONE"
+
 
     if key == "Print": makeScreenshots()
 
Index: gzz/gzz/view/xubuoy.py
diff -u gzz/gzz/view/xubuoy.py:1.36 gzz/gzz/view/xubuoy.py:1.37
--- gzz/gzz/view/xubuoy.py:1.36 Sun Dec  1 00:38:51 2002
+++ gzz/gzz/view/xubuoy.py      Sun Dec  1 17:39:35 2002
@@ -78,22 +78,22 @@
 GL.setDebugVar("JNI.fps", 1)
 # Show the intended screen size
 def bg(vs):
-    vs.map.put(background((0.3,0.5,0.4)))
-    vs.map.put(GLCache.getCallList("""
-       Disable TEXTURE_2D
-       LineWidth 2
-       Color 0 0 0
-       Begin LINE_LOOP
-       Vertex 0 0
-       Vertex 0 %(h)s
-       Vertex %(w)s %(h)s
-       Vertex %(w)s 0
-       End
-       Enable TEXTURE_2D
-    """ % { "w": screensize[0], "h": screensize[1] } ) )
-    #fps = vs.coords.ortho(0, 10, 10, 20, 30.5, 30.5)
-    #vs.matcher.add(fps, "FPS")
-    #vs.map.put(fps_text, fps, 0)
+    if 0:
+       vs.map.put(GLCache.getCallList("""
+           Disable TEXTURE_2D
+           LineWidth 2
+           Color 0 0 0
+           Begin LINE_LOOP
+           Vertex 0 0
+           Vertex 0 %(h)s
+           Vertex %(w)s %(h)s
+           Vertex %(w)s 0
+           End
+           Enable TEXTURE_2D
+       """ % { "w": screensize[0], "h": screensize[1] } ) )
+       #fps = vs.coords.ortho(0, 10, 10, 20, 30.5, 30.5)
+       #vs.matcher.add(fps, "FPS")
+       #vs.map.put(fps_text, fps, 0)
     
 style = gzz.client.GraphicsAPI.getInstance().getTextStyle("SansSerif", 
java.awt.Font.PLAIN, 10)
 contview = gzz.view.LinebrokenCellContentView(style)
@@ -155,7 +155,7 @@
             pass
 
        self.eye = 0.2
-       self.buoyscale = 1300
+       self.buoyscale = 1600
 
     def add(self, vs, importance, floater, 
                        maincs, globalview = None,
@@ -283,6 +283,7 @@
     # xxx
     return cell.t().startswith("?")
 
+
 class XuPDFScene_PDFContext:
     def __init__(self, linkspace, win=None):
         self.linkspace = linkspace
@@ -291,54 +292,56 @@
        self.win = win
        self.modes = [
                Mode(
-                   mag=(screensize[1]*1.6,screensize[1]/40),
+                   mag=(1.6,1.0/40),
                    context=1,
-                   movefocus=0,
-                   eye = 0.2,
+                   movefocus=.5,
+                   eye = 0.25,
                ),
                Mode(
-                   mag=(screensize[1]/4,screensize[1]/4), # full-screen
+                   mag=(1.0/4,1.0/4), # full-screen
                    context=0,
                    movefocus=1,
                    eye = 0.2,
                ),
                Mode(
-                   mag=(screensize[1]/2,screensize[1]/2), # full-screen
+                   mag=(1.0/2,1.0/2), # full-screen
                    context=0,
                    movefocus=1,
                    eye = 0.2,
                ),
                Mode(
-                   mag=(screensize[1],screensize[1]), # full-screen
+                   mag=(1,1), # full-screen
                    context=0,
                    movefocus=1,
                    eye = 0.2,
                ),
                Mode(
-                   mag=(screensize[1]*4,screensize[1]*4), # full-screen
+                   mag=(4,4), # full-screen
                    context=0,
                    movefocus=1,
                    eye = 0.2,
                ),
                Mode(
-                   mag=(screensize[1]*2,screensize[1]/2), # full-screen
+                   mag=(2,1.0/2), # full-screen
                    context=0,
                    movefocus=1,
                    eye = 0.2,
                ),
        ]
 
-       self.ctrx = screensize[0]/2
-       self.ctry = screensize[1]/2
+       self.ctrx = 1.0/2
+       self.ctry = 1.0/2
 
-       self.rad = screensize[0] * 5/12  
+       self.rad = [5.0/12, 4.0/12]
 
-       self.nadir = (self.ctrx, screensize[1]*2)
+       self.nadir = [(self.ctrx, 2),
+                       (self.ctrx, 10000)]
        self.clip = 0
        self.selectCS = None
        self.currentvs = None
         self.corner1 = None
-        
+       self.bgcolor = (.3,.5,.6)
+
     def key(self, key):
        global currentScene
        if self.win:
@@ -457,6 +460,14 @@
            AbstractUpdateManager.setNoAnimation()
            AbstractUpdateManager.chg()
            self.moveToCell(self.cursor)
+       elif key == 'n': # Change nadir
+           rotatelist(self.nadir)
+           AbstractUpdateManager.chg()
+           self.moveToCell(self.cursor)
+       elif key == 'd': # Change radius
+           rotatelist(self.rad)
+           AbstractUpdateManager.chg()
+           self.moveToCell(self.cursor)
         else:
             return 1 # not handled
             
@@ -582,9 +593,12 @@
            AbstractUpdateManager.chg()
 
     def scene(self, vs):
-       bg(vs)
+       vs.map.put(background(self.bgcolor))
+
+       swidth = vs.size.width
+       sheight = vs.size.height
 
-       nadircs = vs.translateCS(0, "NAD", *self.nadir)
+       nadircs = vs.translateCS(0, "NAD", self.nadir[0][0] * swidth, 
self.nadir[0][1] * sheight)
 
        # projx = self.ctrx + 1.5*self.rad
        # fbuoyparams = (self.ctrx, self.ctry, self.rad, 
@@ -598,32 +612,35 @@
        #                   self.rad, projx, self.ctry, 0)
        # vs.matcher.add(cs1, self.cursor.getId()+"__buo")
 
-       projdist = self.rad
+       projrad = self.rad[0] * swidth
+       ctrx = swidth * self.ctrx
+       ctry = sheight * self.ctry
 
-       bf = gzz.vob.buoy.CircleFloater4(vs, 0, self.ctrx, self.ctry,
-           self.rad, self.ctrx - projdist, self.ctry)
-       bfforw = gzz.vob.buoy.CircleFloater4(vs, 0, self.ctrx, self.ctry, 
-           self.rad, self.ctrx + projdist, self.ctry)
+       bf = gzz.vob.buoy.CircleFloater4(vs, 0, ctrx, ctry,
+           projrad, ctrx - projrad, ctry)
+       bfforw = gzz.vob.buoy.CircleFloater4(vs, 0, ctrx, ctry, 
+           projrad, ctrx + projrad, ctry)
 
 
-       cs1 = vs.coords.affineCoordsys(0, 0, self.ctrx, self.ctry, 1, 0, 0, 1)
+       cs1 = vs.coords.affineCoordsys(0, 0, ctrx, ctry, 1, 0, 0, 1)
        vs.matcher.add(cs1, self.cursor.getId()) 
 
        cs1_nad = vs.coords.nadirOrigin(cs1, nadircs)
        vs.matcher.addSub(cs1, cs1_nad, "N")
        cs1 = cs1_nad
 
-       if self.modes[0].movefocus:
-           focusy_at = globaly * screensize[1]
-       else:
-           focusy_at = self.ctry
+       mf = self.modes[0].movefocus
+       focusy_at = mf * globaly * sheight + (1-mf) * ctry
 
        # The buoy cs is centered
-       focusy_at -= self.ctry
+       focusy_at -= ctry
 
        eye = self.modes[0].eye
+       mag = (self.modes[0].mag[0] * sheight,
+               self.modes[0].mag[1] * sheight)
+       print "MAG: ",mag, eye
        cs1_zoom= vs.coords.distort(cs1, 0, focusy_at, 
-           eye, eye, *(self.modes[0].mag))
+           eye, eye, *mag)
        vs.matcher.add(cs1_zoom, self.cursor.getId()+"__bulg") 
 
        cs1_trans = vs.coords.translate(cs1_zoom, -globalx, -globaly + 
focusy_at)




reply via email to

[Prev in Thread] Current Thread [Next in Thread]